<?php
/**
 * Implements functions that are useful when using with the Fashion Traffic WordPress plugin.
 *
 * @author Mike Schinkel <mike@newclarity.net>
 *
 * @since 1.0.0
 *
 */

/**
 * Removes action that generates admin CSS for Fashion Traffic plugin.
 * This function needs to be called from within another hook such as
 * 'init' priority 10 or later. Can also be called in 'admin_init'.
 *
 * If you use this function you should test to see if function exists
 * before calling it to ensure your site doesn't crash if the plugin
 * is deactivated:
 *
 * 		if ( function_exists( 'remove_fashiontraffic_admin_css' ) )
 *       remove_fashiontraffic_admin_css();
 *
 * @since 1.0.0
 */
function remove_fashiontraffic_admin_css() {
	remove_action( 'admin_head', array( FashionTraffic_Plugin::self(), 'admin_head' ), 0 );
}

/**
 * Register a (list of) post type(s) to have Fashion Traffic metaboxes.
 *
 * By default and $post_type == 'post' will get a Fashion Traffic metabox.
 * This will explicitly mark a post as expecting a Fashion Traffic metabox, if needed.
 *
 * Use this method in 'admin_init' hook.
 *
 * @param string|array $post_types One of more post types to register.
 * @since 1.0.0
 */
function register_fashiontraffic_post_type( $post_types ) {
	_assign_fashiontraffic_post_type( $post_types, true );
}

/**
 * Removes a (list of) post type(s) to from having Fashion Traffic metaboxes.
 *
 * By default and $post_type == 'post' will get a Fashion Traffic metabox.
 * This will explicitly mark a post as expecting to NOT have a Fashion Traffic metabox.
 *
 * Use this method in 'admin_init' hook.
 *
 * @param string|array $post_types One of more post types to remove.
 *
 * @since 1.0.0
 */
function remove_fashiontraffic_post_type( $post_types ) {
	_assign_fashiontraffic_post_type( $post_types, false );
}
/**
 * "Private" function to support this public functions:
 *
 * 		remove_fashiontraffic_post_type()
 * 		register_fashiontraffic_post_type()
 *
 * @param string|array $post_types One of more post types to remove.
 * @param bool $enable true to register, false to remove.
 *
 * @since 1.0.0
 */
function _assign_fashiontraffic_post_type( $post_types, $enable ) {
	global $wp_post_types;

	/**
	 * If just one past type passed, convert to array so we can
	 * use the same code to process as for a list of post types
	 */
	if ( is_string( $post_types ) )
		$post_types = (array) $post_types;

	/**
	 * Loop through the post types
	 */
	foreach( $post_types as $index => $post_type ) {
		/**
		 * If this post type is indeed a valid post type
		 */
		if ( isset( $wp_post_types[$post_type] ) )
			/**
			 * Set this post type's Fashion Traffic property to be the value
			 * passed for $enable. If $enable == true this mean this post type
			 * will get a Fashion Traffic metabox, or it explicit won't get
			 * a Fashion Traffic metabox if $enable == false.
			 */
			$wp_post_types[$post_type]->fashiontraffic = $enable;
	}
}
